@@ -10,17 +10,16 @@ import time
 
 LOGGER = logging.getLogger(__name__)
 
-class ChooseFromHistoryAction (deskbar.interfaces.Action):
+class EmptyHistoryAction (deskbar.interfaces.Action):
     """
-    This will be displayed always at the top of the history
-    and is just there to display "Choose action"
+    This will be displayed if history is empty
     """
     
     def __init__(self):
         deskbar.interfaces.Action.__init__(self, "")
         
     def get_verb(self):
-        return _("<i>Choose action</i>")
+        return _("<i>Empty history</i>")
     
     def activate(self, text=None):
         pass
@@ -42,7 +41,8 @@ class DeskbarHistory (gtk.ListStore) :
     """
     
     __gsignals__ = {
-        "cleared" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
+        "cleared" :        (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
+        "action-added" :   (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [str, gobject.TYPE_PYOBJECT]),
     }
     __instance = None
     (COL_TIME, COL_TEXT, COL_ACTION) = range(3)
@@ -57,10 +57,8 @@ class DeskbarHistory (gtk.ListStore) :
         self.set_sort_order (gtk.SORT_DESCENDING)
         self.set_sort_func (self.COL_TIME, self.__sort_actions)
         
-        self._index = 0 # We don't want to show ChooseFromHistoryAction
+        self._index = -1
         self.set_max_history_items(max_history_items)
-        
-        self.append(0, "", ChooseFromHistoryAction())
     
     def set_sort_order(self, order):
         """
@@ -98,25 +96,20 @@ class DeskbarHistory (gtk.ListStore) :
         """
         action1 = model[iter1][self.COL_ACTION]
         action2 = model[iter2][self.COL_ACTION]
-        
-        if isinstance(action1, ChooseFromHistoryAction):
+                
+        if self[iter1][self.COL_TIME] > self[iter2][self.COL_TIME] :
             return 1
-        elif isinstance(action2, ChooseFromHistoryAction):
+        else:
             return -1
-        else:        
-            if self[iter1][self.COL_TIME] > self[iter2][self.COL_TIME] :
-                return 1
-            else:
-                return -1
     
     def clear (self):
         """
         Clear the history
         """
         gtk.ListStore.clear(self)
-        self.append("", "", ChooseFromHistoryAction())
         self._index = -1
         self.emit("cleared")
+        self.append("", "", EmptyHistoryAction())
     
     def load (self):
         """
@@ -144,6 +137,9 @@ class DeskbarHistory (gtk.ListStore) :
             LOGGER.error("Could not restore history")
             LOGGER.exception(e)
             pass
+        
+        if len(self) == 0:
+            self.append(0, "", EmptyHistoryAction())
 
     def save (self):
         """
@@ -151,7 +147,7 @@ class DeskbarHistory (gtk.ListStore) :
         """
         save = []
         for timestamp, text, action in self:
-            if isinstance(action, ChooseFromHistoryAction):
+            if not isinstance(action, EmptyHistoryAction):
                 save.append((timestamp, text, action))
         
         try:
@@ -164,6 +160,7 @@ class DeskbarHistory (gtk.ListStore) :
         """
         *Do not* use this method. Always use L{add}.
         """
+        self.emit('action-added', text, action)
         self.append_method (self, (timestamp, text, action))
     
     def prepend (self, timestamp, text, action):
@@ -181,7 +178,10 @@ class DeskbarHistory (gtk.ListStore) :
         """
         assert text != None and action != None
         
-        if isinstance(action, ChooseFromHistoryAction):
+        if not isinstance(action, deskbar.interfaces.Action):
+            raise TypeError("Action must be a deskbar.interfaces.Action instance")
+        
+        if isinstance(action, EmptyHistoryAction):
             return
         if action.skip_history():
             self.reset()
@@ -189,6 +189,10 @@ class DeskbarHistory (gtk.ListStore) :
         
         for idx, val in enumerate(self):
             htime, htext, haction = val
+            if isinstance(haction, EmptyHistoryAction):
+                self.remove (self.get_iter_from_string (str(idx)))
+                continue
+                
             if (action.get_hash() == haction.get_hash() and action.__class__.__name__ == haction.__class__.__name__):
                 self.remove (self.get_iter_from_string (str(idx)))
                 break
@@ -225,8 +229,8 @@ class DeskbarHistory (gtk.ListStore) :
         """
         Reset index
         """
-        if self._index != 0:
-            self._index = 0
+        if self._index != -1:
+            self._index = -1
             return self.get_current()
     
     def last(self):
@@ -248,7 +252,7 @@ class DeskbarHistory (gtk.ListStore) :
         """
         Get action where the current index points to
         """
-        if self._index == 0:
+        if self._index == -1:
             return None
         col_id, direction = self.get_sort_column_id()
         index = self._index
